# AI鸟类数据库结构

## Region（地区表）
- **基础字段**
  - objectId
  - createdAt
  - updatedAt
- **信息字段**
  - name: String
  - description: String
  - climate: String
  - terrain: String
  - areaSize: Number
  - bestSeason: String
- **地理信息**
  - featureTags: Array<String>
  - centerLocation: GeoPoint
  - mapImage: File
- **统计字段**
  - popularity: Number

## Bird（鸟类表）
- **基础字段**
  - objectId
  - createdAt
  - updatedAt
- **分类信息**
  - name: String
  - scientificName: String
  - family: String
- **特征描述**
  - description: String
  - habitats: Array<String>
  - size: String
  - color: String
- **生态信息**
  - conservationStatus: String
  - seasons: Array<String>
  - diet: String
- **媒体**
  - image: File

## BirdRoute（观鸟路线表）
- **基础字段**
  - objectId
  - createdAt
  - updatedAt
- **基本信息**
  - name: String
  - description: String
  - region: Pointer<Region>
- **路线特征**
  - length: Number
  - difficulty: Number
  - estimatedTime: Number
  - pathPoints: Array<GeoPoint>
- **观鸟信息**
  - commonBirds: Array<Pointer<Bird>>
  - bestMonths: Array<String>
- **位置信息**
  - startPoint: String
  - endPoint: String
- **评价信息**
  - rating: Number
  - popularity: Number
- **设施**
  - facilities: Array<String>
- **媒体**
  - routeImage: File

## UserObservation（用户观察记录）
- **关联信息**
  - user: Pointer<User>
  - bird: Pointer<Bird>
  - route: Pointer<BirdRoute>
- **观察数据**
  - observationTime: Date
  - location: GeoPoint
  - weather: String
  - notes: String
  - confidence: Number
- **媒体**
  - photo: File

## RouteReview（路线评价表）
- **关联信息**
  - user: Pointer<User>
  - route: Pointer<BirdRoute>
- **评价内容**
  - rating: Number
  - comment: String
  - tags: Array<String>
- **观察数据**
  - visitDate: Date
  - birdsSeen: Array<Pointer<Bird>>

## 关系图
```mermaid
graph TD
  Region -->|contains| BirdRoute
  BirdRoute -->|has| UserObservation
  BirdRoute -->|has| RouteReview
  Bird -->|observed| UserObservation
  Bird -.->|found_in| BirdRoute